from .token import Token, TokenType
import re


class Lexer:
    """Lexer for 1 file"""

    content: str
    index: int

    def __init__(self, content: str) -> None:
        self.content = content
        self.index = 0

    def skip_whitespace(self) -> None:
        while self.content[self.index] in ["\n", "\t", " "]:
            self.index += 1

    def peek(self, offset: int) -> str:
        """Returns the character at the offset+index"""
        return self.content[self.index + offset]

    def char(self) -> str:
        """Returns the current char"""
        return self.content[self.index]

    def nchr(self) -> str:
        self.index += 1
        return self.char()

    def next(self) -> Token:
        self.skip_whitespace()
        t = Token()
        c = self.char()

        if c == "/":
            c1 = self.nchr()
            if c1 == "/":
                c2 = self.nchr()
                if c2 == "-":
                    t.type = TokenType.MULTILINE_COMMENT_START
                    t.value = "//-"
                else:
                    t.value = TokenType.COMMENT_START
                    t.value = "//"
                    self.index -= 1

        elif c == "-":
            c1 = self.nchr()
            if c1 == "/":
                c2 = self.nchr()
                if c2 == "/":
                    t.type = TokenType.MULTILINE_COMMENT_END
                    t.value = "-//"
            else:
                t.type = TokenType.OP_MINUS
                t.value = "-"
                self.index -= 1

        return t
